Khi.Square.Per.Cell: Khi Square Per Cell

Description Usage Arguments Value

View source: R/Khi.Square.Per.Cell.R

Description

It makes Khi Square Per Cell for dataframe with the total number of case per column

Usage

1
2
3
4
5
6
7
Khi.Square.Per.Cell(
  df,
  n.Segmentation,
  decimais = 3,
  decimaisPorcentage = 0,
  dec.Global.p_Value = 6
)

Arguments

df

is a dataframe

n.Segmentation

TRUE if exits in df the total number of case per each column

decimais

the number of decimals for the results

decimaisPorcentage

decimals used for percentage results

dec.Global.p_Value

decimals for the global khi square reult

Value

Khi Square Per Cell in different presentation options


DavyLectures/Khi2PerCell documentation built on Dec. 17, 2021, 4:09 p.m.